CNV Classification Classifies the CNV results into loss, gain, or no alteration for each observation and chromosome arm.
Source:R/CNVclassification.R
CNVClassification.RdCNV Classification Classifies the CNV results into loss, gain, or no alteration for each observation and chromosome arm.
Usage
CNVClassification(seuratObj, peaks = c(-0.1, 0, 0.1))Arguments
- seuratObj
A Seurat object containing the results of the CNV analysis (e.g., from
fastCNV).- peaks
A numeric vector containing the thresholds for classifying CNVs. The default is
c(-0.1, 0, 0.1), which defines:Loss: CNV scores below
-0.1No alteration: CNV scores between
-0.1and0.1Gain: CNV scores above
0.1