Skip to contents

CNV Classification for a Given Vector Classifies each CNV value in a vector as "loss", "gain", or "no alteration" based on specified thresholds.

Usage

classifyCNV(cnv_vector, peaks)

Arguments

cnv_vector

A numeric vector of CNV scores for a given chromosome arm.

peaks

A numeric vector containing the thresholds for classification. The default is c(-0.1, 0, 0.1):

  • Loss: CNV values below the first threshold (peaks[1]).

  • Gain: CNV values above the third threshold (peaks[3]).

  • No alteration: CNV values between the first and third thresholds.

Value

A character vector of classifications for each CNV value in the input vector, with possible values of "loss", "gain", or "no_alteration".