This function retrieves gene information from the Ensembl database using the specified filters. It can either fetch the latest data or use cached data if available.
Arguments
- filters
A character vector of filters to be applied in the query. These filters determine which genes and their associated information are returned from the Ensembl database.
- cache
Logical. If
TRUE, the function will use cached data if available. IfFALSE, it will download the latest version of the gene data from Ensembl.