Skip to contents

This function checks if the user is working on ubuntu 22 Raster_by_magick does not work under ubuntu 22 so the parameter on the heatmap is changed if it returns TRUE

Usage

is_ubuntu22()

Value

TRUE or FALSE