Aggregate Observations by Cell Type for CNV Analysis Aggregates observations with the same cell types to increase counts per observation, improving Copy Number Variation (CNV) computation.
Source:R/prepareCountsForCNV.R
prepareCountsForCNVAnalysis.RdAggregate Observations by Cell Type for CNV Analysis Aggregates observations with the same cell types to increase counts per observation, improving Copy Number Variation (CNV) computation.
Usage
prepareCountsForCNVAnalysis(
seuratObj,
sampleName = NULL,
referenceVar = NULL,
aggregateByVar = TRUE,
aggregFactor = 15000,
seuratClusterResolution = 0.8,
reClusterSeurat = FALSE
)Arguments
- seuratObj
A Seurat object containing the data.
- sampleName
A character string specifying the sample name.
- referenceVar
The name of the metadata column in the Seurat object that contains reference annotations.
- aggregateByVar
Logical. If
TRUE(default), aggregates observations based onreferenceVarannotations.- aggregFactor
Integer. The target number of counts per observation (default =
15000).- seuratClusterResolution
Numeric. The resolution used for Seurat clustering (default =
0.8).- reClusterSeurat
Logical. If
TRUE, re-runs clustering on the Seurat object.